@@ -1617,7 +1617,8 @@ StringEnd()
     case AKA:
       if (curr->w_title == curr->w_akabuf && !*curr->w_string)
 	break;
-      ChangeAKA(curr, curr->w_string, strlen(curr->w_string));
+      if (curr->w_dynamicaka)
+	ChangeAKA(curr, curr->w_string, strlen(curr->w_string));
       if (!*curr->w_string)
 	curr->w_autoaka = curr->w_y + 1;
       break;
@@ -2502,13 +2503,13 @@ int n, ys, ye, bce;
     return;
   if (n > 0)
     {
+      if (ye - ys + 1 < n)
+	n = ye - ys + 1;
       if (n > 256)
 	{
 	  MScrollV(p, n - 256, ys, ye, bce);
 	  n = 256;
 	}
-      if (ye - ys + 1 < n)
-	n = ye - ys + 1;
 #ifdef COPY_PASTE
       if (compacthist)
 	{
@@ -2562,14 +2563,14 @@ int n, ys, ye, bce;
     }
   else
     {
-      if (n < -256)
-	{
-	  MScrollV(p, n + 256, ys, ye, bce);
-	  n = -256;
-	}
       n = -n;
       if (ye - ys + 1 < n)
 	n = ye - ys + 1;
+      if (n > 256)
+	{
+	  MScrollV(p, - (n - 256), ys, ye, bce);
+	  n = 256;
+	}
 
       ml = p->w_mlines + ye;
       /* Clear lines */
