@@ -1,11 +1,16 @@
-/* Copyright (c) 1993-2002
+/* Copyright (c) 2008, 2009
+ *      Juergen Weigert (jnweiger@immd4.informatik.uni-erlangen.de)
+ *      Michael Schroeder (mlschroe@immd4.informatik.uni-erlangen.de)
+ *      Micah Cowan (micah@cowan.name)
+ *      Sadrul Habib Chowdhury (sadrul@users.sourceforge.net)
+ * Copyright (c) 1993-2002, 2003, 2005, 2006, 2007
  *      Juergen Weigert (jnweiger@immd4.informatik.uni-erlangen.de)
  *      Michael Schroeder (mlschroe@immd4.informatik.uni-erlangen.de)
  * Copyright (c) 1987 Oliver Laumann
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
+ * the Free Software Foundation; either version 3, or (at your option)
  * any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,9 +19,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program (see the file COPYING); if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
+ * along with this program (see the file COPYING); if not, see
+ * http://www.gnu.org/licenses/, or contact Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
  *
  ****************************************************************
  */
@@ -173,6 +178,10 @@ struct term term[T_N] =
 
 /* keycaps */
 /* define T_CAPS */
+
+/* mouse */
+  { "Km", T_STR  }, KMAPDEF("\033[M")		KMAPMDEF("\222")
+
 /* nolist */
   { "k0", T_STR  }, KMAPDEF("\033[10~")
   { "k1", T_STR  }, KMAPDEF("\033OP")
@@ -196,6 +205,10 @@ struct term term[T_N] =
   { "F8", T_STR  },
   { "F9", T_STR  },
   { "FA", T_STR  },
+  { "FB", T_STR  },
+  { "FC", T_STR  },
+  { "FD", T_STR  },
+  { "FE", T_STR  },
 
   { "kb", T_STR  },
   { "K1", T_STR  },
@@ -231,7 +244,7 @@ struct term term[T_N] =
   { "kh", T_STR  }, KMAPDEF("\033[1~") KMAPMDEF("\201")
   { "@1", T_STR  },
   { "kH", T_STR  }, KMAPDEF("\033[4~") KMAPMDEF("\205")
-  { "@7", T_STR  },
+  { "@7", T_STR  }, KMAPDEF("\033[4~") KMAPMDEF("\205")
   { "kN", T_STR  }, KMAPDEF("\033[6~") KMAPMDEF("\006")
   { "kP", T_STR  }, KMAPDEF("\033[5~") KMAPMDEF("\002")
   { "kI", T_STR  }, KMAPDEF("\033[2~")
